# pymacaron-aws

A deployment pipeline for pymacaron microservices, deploying them as Docker
containers on amazon Elastic Beanstalk.

See more at [pymacaron.com](http://pymacaron.com/aws.html)


## Author

Erwan Lemonnier<br/>
[github.com/pymacaron](https://github.com/pymacaron)</br>
[github.com/erwan-lemonnier](https://github.com/erwan-lemonnier)<br/>
[www.linkedin.com/in/erwan-lemonnier/](https://www.linkedin.com/in/erwan-lemonnier/)